package
Version:
v0.0.0-...-38cc344
Opens a new window with list of versions in this module.
Published: Mar 22, 2019
License: MIT
Opens a new window with license information.
Imports: 13
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
SetupAPI : initiates API routes
type Folder struct {
Name string `json:"name"`
HasProject bool `json:"hasProject"`
}
Folder : test stuff
Source Files
¶
Click to show internal directories.
Click to hide internal directories.